@@ -1,4 +1,6 @@
-use crate::{Endpoint, Request, Response, Result};
+use std::future::Future;
+
+use crate::{Endpoint, Request, Response};
 
 /// Endpoint for the [`before`](super::EndpointExt::before) method.
 pub struct Before<E, F> {
@@ -14,12 +16,13 @@ impl<E, F> Before<E, F> {
 }
 
 #[async_trait::async_trait]
-impl<E, F> Endpoint for Before<E, F>
+impl<E, F, Fut> Endpoint for Before<E, F>
 where
     E: Endpoint,
-    F: Fn(Request) -> Result<Request> + Send + Sync + 'static,
+    F: Fn(Request) -> Fut + Send + Sync + 'static,
+    Fut: Future<Output = Request> + Send + 'static,
 {
-    async fn call(&self, req: Request) -> Result<Response> {
-        self.inner.call((self.f)(req)?).await
+    async fn call(&self, req: Request) -> Response {
+        self.inner.call((self.f)(req).await).await
     }
 }
